AgentCard

Struct AgentCard 

pub struct AgentCard {
Show 18 fields pub name: String, pub description: String, pub version: String, pub protocol_version: String, pub url: String, pub preferred_transport: TransportProtocol, pub capabilities: AgentCapabilities, pub default_input_modes: Vec<String>, pub default_output_modes: Vec<String>, pub skills: Vec<AgentSkill>, pub provider: Option<AgentProvider>, pub additional_interfaces: Vec<AgentInterface>, pub documentation_url: Option<String>, pub icon_url: Option<String>, pub security: Vec<HashMap<String, Vec<String>>>, pub security_schemes: Option<HashMap<String, SecurityScheme>>, pub signatures: Vec<AgentCardSignature>, pub supports_authenticated_extended_card: Option<bool>,
}
The AgentCard is a self-describing manifest for an agent.

Fields

name: String

A human-readable name for the agent.

description: String

A human-readable description of the agent.

version: String

The agent’s own version number.

protocol_version: String

The version of the A2A protocol this agent supports.

url: String

The preferred endpoint URL for interacting with the agent.

preferred_transport: TransportProtocol

The transport protocol for the preferred endpoint.

capabilities: AgentCapabilities

A declaration of optional capabilities supported by the agent.

default_input_modes: Vec<String>

Default set of supported input MIME types for all skills.

default_output_modes: Vec<String>

Default set of supported output MIME types for all skills.

skills: Vec<AgentSkill>

The set of skills that the agent can perform.

provider: Option<AgentProvider>

Information about the agent’s service provider.

additional_interfaces: Vec<AgentInterface>

A list of additional supported interfaces (transport and URL combinations).

documentation_url: Option<String>

An optional URL to the agent’s documentation.

icon_url: Option<String>

An optional URL to an icon for the agent.

security: Vec<HashMap<String, Vec<String>>>

A list of security requirement objects that apply to all agent interactions.

security_schemes: Option<HashMap<String, SecurityScheme>>

A declaration of the security schemes available to authorize requests.

signatures: Vec<AgentCardSignature>

JSON Web Signatures computed for this AgentCard.

supports_authenticated_extended_card: Option<bool>

If true, the agent can provide an extended agent card to authenticated users.

Implementations

Source

impl AgentCard

pub fn new( name: impl Into<String>, description: impl Into<String>, version: impl Into<String>, url: impl Into<String>, ) -> AgentCard

Create a new AgentCard with minimal required fields

pub fn with_name(self, name: impl Into<String>) -> AgentCard

Set the agent’s name

pub fn with_description(self, description: impl Into<String>) -> AgentCard

Set the agent’s description

pub fn with_version(self, version: impl Into<String>) -> AgentCard

Set the agent’s version

pub fn with_protocol_version( self, protocol_version: impl Into<String>, ) -> AgentCard

Set the A2A protocol version

pub fn with_url(self, url: impl Into<String>) -> AgentCard

Set the agent’s URL endpoint

pub fn with_preferred_transport(self, transport: TransportProtocol) -> AgentCard

Set the preferred transport protocol

pub fn with_capabilities(self, capabilities: AgentCapabilities) -> AgentCard

Set the agent’s capabilities

pub fn with_streaming(self, enabled: bool) -> AgentCard

Enable streaming capability

pub fn with_push_notifications(self, enabled: bool) -> AgentCard

Enable push notifications capability

pub fn with_state_transition_history(self, enabled: bool) -> AgentCard

Enable state transition history capability

pub fn add_extension(self, extension: AgentExtension) -> AgentCard

Add an extension to the capabilities

pub fn with_default_input_modes(self, modes: Vec<String>) -> AgentCard

Set default input modes (replaces existing)

pub fn add_input_mode(self, mode: impl Into<String>) -> AgentCard

Add a default input mode

pub fn with_default_output_modes(self, modes: Vec<String>) -> AgentCard

Set default output modes (replaces existing)

pub fn add_output_mode(self, mode: impl Into<String>) -> AgentCard

Add a default output mode

pub fn with_skills(self, skills: Vec<AgentSkill>) -> AgentCard

Set skills (replaces existing)

pub fn add_skill(self, skill: AgentSkill) -> AgentCard

Add a skill

pub fn add_skill_with<F>( self, id: impl Into<String>, name: impl Into<String>, f: F, ) -> AgentCard

Create a skill using a builder pattern and add it

pub fn with_provider( self, organization: impl Into<String>, url: impl Into<String>, ) -> AgentCard

Set the provider information

pub fn with_additional_interfaces( self, interfaces: Vec<AgentInterface>, ) -> AgentCard

Set additional interfaces (replaces existing)

pub fn add_interface( self, transport: TransportProtocol, url: impl Into<String>, ) -> AgentCard

Add an additional interface

pub fn with_documentation_url(self, url: impl Into<String>) -> AgentCard

Set documentation URL

pub fn with_icon_url(self, url: impl Into<String>) -> AgentCard

Set icon URL

pub fn with_security( self, security: Vec<HashMap<String, Vec<String>>>, ) -> AgentCard

Set security requirements

pub fn add_security_requirement( self, requirement: HashMap<String, Vec<String>>, ) -> AgentCard

Add a security requirement

pub fn with_security_schemes( self, schemes: HashMap<String, SecurityScheme>, ) -> AgentCard

Set security schemes

pub fn with_authenticated_extended_card(self, supported: bool) -> AgentCard

Enable authenticated extended card support

pub fn with_signatures(self, signatures: Vec<AgentCardSignature>) -> AgentCard

Set signatures (replaces existing)

pub fn add_signature(self, signature: AgentCardSignature) -> AgentCard

Add a signature