pub struct AuthenticatedExtendedCardNotConfiguredError {
pub code: i32,
pub message: String,
pub data: Option<Value>,
}Expand description
An A2A-specific error indicating that the agent does not have an Authenticated Extended Card configured.
Fields
code: i32The error code for when an authenticated extended card is not configured.
message: StringThe error message.
data: Option<Value>A primitive or structured value containing additional information about the error.