pub struct InternalError {
pub code: i32,
pub message: String,
pub data: Option<Value>,
}Expand description
An error indicating an internal error on the server.
Fields
code: i32The error code for an internal server error.
message: StringThe error message.
data: Option<Value>A primitive or structured value containing additional information about the error.