pub struct InvalidAgentResponseError {
pub code: i32,
pub message: String,
pub data: Option<Value>,
}Expand description
An A2A-specific error indicating that the agent returned a response that does not conform to the specification for the current method.
Fields
code: i32The error code for an invalid agent response.
message: StringThe error message.
data: Option<Value>A primitive or structured value containing additional information about the error.