pub struct PushNotificationNotSupportedError {
pub code: i32,
pub message: String,
pub data: Option<Value>,
}Expand description
An A2A-specific error indicating that the agent does not support push notifications.
Fields
code: i32The error code for when push notifications are not supported.
message: StringThe error message.
data: Option<Value>A primitive or structured value containing additional information about the error.