pub struct UnsupportedOperationError {
pub code: i32,
pub message: String,
pub data: Option<Value>,
}Expand description
An A2A-specific error indicating that the requested operation is not supported by the agent.
Fields
code: i32The error code for an unsupported operation.
message: StringThe error message.
data: Option<Value>A primitive or structured value containing additional information about the error.