Module types

Module types 

Re-export A2A protocol types so downstream crates can ensure they use the exact same type definitions as the client.

Re-exports

pub use a2a_types as v1;

Structs

JSONRPCError
Represents a JSON-RPC 2.0 Error object, included in an error response.
JSONRPCErrorResponse
Represents a JSON-RPC 2.0 Error Response object.

Enums

JSONRPCId
Represents a JSON-RPC 2.0 identifier, which can be a string, number, or null.